@@ -10,7 +10,7 @@ opts.neutrinoPrimary_direction = [0,0,1]
 opts.neutrinoPrimary_pdf_model = 'CT10nlo'
 opts.neutrinoPrimary_target = 2212
 
-import nugen as  nugen
+import nupropagator.nugen as  nugen
 import numpy as np
 
 
